/*
	This do file complies all the commuting zone level files into one main sample for
	commuting zone level regressions. It classifies the data into 3 sectors: the exposed sector,
	the non-exposed tradable sector and the non-exposed non-tradable sector
	
	Last edited: August 25, 2018
	
*/


clear all
set more off

*Define Directories
local dir "..." //Insert your directory path
local netsdir "`dir'/AGNR-JobFlowsChinaShock/data/nets/"
local cbpdir "`dir'/AGNR-JobFlowsChinaShock/data/cbp/"
local tradedir "`dir'/AGNR-JobFlowsChinaShock/data/trade/"
local datadir "`dir'/AGNR-JobFlowsChinaShock/data/sample/"

* Load NETS data at the czone-industry level
use "`netsdir'national/nets_czone_industry.dta", clear

*merge in AADHP's classification into 3 sectors. It comes from "H:/My Drive/AADHP-JOLE-Sag-Replication-2015-05-13/dta/cbp/county/clean/classification/industry_classification.dta" 
merge m:1 sic87dd using "`cbpdir'classification/industry_classification_AADHP.dta", nogenerate

	gen class = .
		replace class = 1 if exposed_directly == 1 | exposed_upstream == 1
		replace class = 2 if (exposed_directly == 0 & exposed_upstream == 0) & tradable == 1
		replace class = 3 if (exposed_directly == 0 & exposed_upstream == 0) & tradable == 0
	assert class != .

collapse (sum) nets*, by(czone class year)

tempfile nets_czone_class
save `nets_czone_class'

* Merge in CBP employment data
use "`cbpdir'emp_counts/cbp_czone_emp_total.dta", clear
keep if year > 1990
rename emp cbp_emp

* Merge in NETS employment data
merge 1:1 year sic87dd czone using "`netsdir'emp_counts/nets_czone_emp_total.dta", nogenerate
replace nets_emp = 0 if nets_emp == . & year > 1991
		
merge m:1 sic87dd using "`cbpdir'classification/industry_classification_AADHP.dta", nogenerate

	gen class = .
		replace class = 1 if exposed_directly == 1 | exposed_upstream == 1
		replace class = 2 if (exposed_directly == 0 & exposed_upstream == 0) & tradable == 1
		replace class = 3 if (exposed_directly == 0 & exposed_upstream == 0) & tradable == 0
	assert class != .
		
collapse (sum) cbp_emp nets_emp, by(czone class year)

merge m:1 year czone class using `nets_czone_class', nogenerate
keep if year < 2012

	* Drop Alaska (FIPS state code 2, CZs 34101 to 34115)
		drop if (czone >= 34101 & czone <= 34115) 

	* Drop Hawaii (FIPS state code 15, CZs 35600 and 34701-34703)
		drop if czone == 35600 | (czone >= 34701 & czone <= 34703)
		

foreach i in "7" "8" "12" {

	label var nets_nochange_empchange_`i' "Employment Change in Establishments with no Employment Change; `i' year changes"
	label var nets_birth_empchange_`i' "Employment Change in New Establishments; `i' year changes"
	label var nets_death_empchange_`i' "Employment Change in Dead Establishments; `i' year changes"
	label var nets_exp_empchange_`i' "Employment Change in Establishments with Employment Expansion; `i' year changes"
	label var nets_con_empchange_`i' "Employment Change in Establishments with Employment Contraction; `i' year changes"
	label var nets_other_empchange_`i' "Employment Change in Establishments Already Died or Not Yet Born; `i' year changes"
	label var nets_nochange_empsum_`i' "Employment Level in Establishments with no Employment Change; `i' year changes"
	label var nets_birth_empsum_`i' "Employment Level in New Establishments; `i' year changes"
	label var nets_death_empsum_`i' "Employment Level in Dead Establishments; `i' year changes"
	label var nets_exp_empsum_`i' "Employment Level in Establishments with Employment Expansion; `i' year changes"
	label var nets_con_empsum_`i' "Employment Level in Establishments with Employment Contraction; `i' year changes"
	label var nets_other_empsum_`i' "Employment Level in Establishments Already Died or Not Yet Born; `i' year changes"

}

	label var cbp_emp "CBP total employment"
	label var nets_emp "NETS total employment "
	label var class "tradable, exposed non-tradable, non-exposed non-tradable"
	label var czone "commuting zone code"

* Merge in NETS employment data by terciles
merge 1:1 year czone class using "H:\My Drive\AGNR-JobFlowsChinaShock\data\nets\county\nets_czone_terciles.dta", nogenerate	
	
* Merge in trade variables
merge m:1 year czone using "`tradedir'raw/trade_czone_variables_cbp.dta", nogenerate
merge m:1 year czone using "`tradedir'raw/trade_czone_variables_nets.dta", nogenerate

	* Drop Alaska (FIPS state code 2, CZs 34101 to 34115)
	drop if (czone >= 34101 & czone <= 34115) 

	* Drop Hawaii (FIPS state code 15, CZs 35600 and 34701-34703)
	drop if czone == 35600 | (czone >= 34701 & czone <= 34703)

* Generate cz level import exposure measures	
foreach i in "7" "8" "12"{
	foreach v in "cbp" "nets"{

	label var d_`v'_import_cz_usch_`i' "Change in U.S. imports from China; `i' year change"
	label var d_`v'_import_cz_otch_`i' "Change in comparison countries' imports from China; `i' year change"
		
		foreach d in "up" "down"{
	
			label var d_`v'_`d'_cz_usch_`i' "First-order `d'stream change in U.S. imports from China;`i' year change"
			label var d_`v'_`d'_cz_otch_`i' "First-order `d'stream change in comparison countries' imports from China; `i' year change"
			label var d_`v'_`d'_LT_cz_usch_`i' "Full `d'stream change in U.S. imports from China;`i' year change"
			label var d_`v'_`d'_LT_cz_otch_`i' "Full `d'stream change in comparison countries' imports from China; `i' year change"
		}
	}
}

	
	
save "`datadir'main_czone.dta", replace




