/*
	This do file constructs measures of PNTR status at the commuting zone level. 
	It takes NTR gaps from our industry level data file and creates CBP and NETS employment weighted 
	measures at the CZONE level
	
	Last edited: November 21, 2017
	
*/


clear all
set more off 

*Define Directories
local dir "..." //Insert your directory path
local pntrdir "`dir'/AGNR-JobFlowsChinaShock/data/pntr/"
local cbpdir "`dir'/AGNR-JobFlowsChinaShock/data/cbp/"
local netsdir "`dir'/AGNR-JobFlowsChinaShock/data/nets/"


* Generating 7, 8, and 12 year differences
foreach t in "7" "8" "12" {
	* load CBP employment counts
	use "`cbpdir'emp_counts/cbp_czone_emp_total.dta", clear
	rename emp cbp_emp
	keep if year > 1990
	
	*merge in industry level PNTR measure
	merge m:1 sic87dd  using "`pntrdir'clean/spread", nogenerate

	egen czonesic=group(czone sic87dd)
	tsset czonesic year

	replace spread=0 if year<2002
	replace up_spread=0 if year<2002
	replace down_spread=0 if year<2002
	replace up_LT_spread=0 if year<2002
	replace down_LT_spread=0 if year<2002

	gen spread_`t'=spread*100/`t'
	gen up_spread_`t'=up_spread*100/`t'
	gen down_spread_`t'=down_spread*100/`t'
	gen up_LT_spread_`t'=up_LT_spread*100/`t'
	gen down_LT_spread_`t'=down_LT_spread*100/`t'

	collapse (mean) cbp_spread_cz_`t'=spread_`t' cbp_up_spread_cz_`t'=up_spread_`t' cbp_down_spread_cz_`t'=down_spread_`t' cbp_up_LT_spread_cz_`t'=up_LT_spread_`t' cbp_down_LT_spread_cz_`t'=down_LT_spread_`t' [aw=L`t'.cbp_emp], by(year czone)

	tempfile cbp_spread_cz_`t'
	save `cbp_spread_cz_`t''
}


foreach t in "7" "8" "12" {
	* load NETS employment counts
	use "`netsdir'emp_counts/nets_czone_emp_total.dta", clear
	keep if year < 2012
	
	*merge in industry level PNTR measure
	merge m:1 sic87dd  using "`pntrdir'clean/spread", nogenerate

	egen czonesic=group(czone sic87dd)
	tsset czonesic year

	replace spread=0 if year<2002
	replace up_spread=0 if year<2002
	replace down_spread=0 if year<2002
	replace up_LT_spread=0 if year<2002
	replace down_LT_spread=0 if year<2002

	gen spread_`t'=spread*100/`t'
	gen up_spread_`t'=up_spread*100/`t'
	gen down_spread_`t'=down_spread*100/`t'
	gen up_LT_spread_`t'=up_LT_spread*100/`t'
	gen down_LT_spread_`t'=down_LT_spread*100/`t'

	collapse (mean) nets_spread_cz_`t'=spread_`t' nets_up_spread_cz_`t'=up_spread_`t' nets_down_spread_cz_`t'=down_spread_`t' nets_up_LT_spread_cz_`t'=up_LT_spread_`t' nets_down_LT_spread_cz_`t'=down_LT_spread_`t' [aw=L`t'.nets_emp], by(year czone)

	tempfile nets_spread_cz_`t'
	save `nets_spread_cz_`t''
}


* merging in all the PNTR measures into one dataset 
use `cbp_spread_cz_7', clear
merge 1:1 year czone using `cbp_spread_cz_8', nogenerate
merge 1:1 year czone using `cbp_spread_cz_12', nogenerate
merge 1:1 year czone using `nets_spread_cz_7', nogenerate
merge 1:1 year czone using `nets_spread_cz_8', nogenerate
merge 1:1 year czone using `nets_spread_cz_12', nogenerate

foreach t in "7" "8" "12" {
	foreach v in "cbp" "nets" {
		foreach d in "spread" "up_spread" "down_spread" "up_LT_spread" "down_LT_spread" {
		label var `v'_`d'_cz_`t' "`v'-adjusted NTR gap annualized" 
		}
	}
}

save "`pntrdir'clean/spread_czone.dta", replace
